**NGUYEN VIET HUNG**

hvnsweeting@gmail.com

DevOps, Linux System Administrator, Python developer

Skills
------

:OS: Ubuntu, Debian, ArchLinux, BSDs
:Configuration management: SaltStack
:Programming language: Python, Bash, PHP, SQL
:SCM: git
:Continuous Integration: Jenkins
:Monitoring: Shinken, NRPE, NSCA, Graphite, Graylog2, Sentry
:Networking: iptables, tcpdump, ngrep, iproute2
:Database: Postgresql, MySQL, sqlite3, mongoDB, ElasticSearch
:Key-Value Cache: Memcached, Redis
:Backup: tar, scp, rsync, s3cmd
:Daemon: NGINX, uwsgi, apache2, vsftpd, rsyncd, OpenLDAP, OpenVPN,
         postfix, dovecot, spamassassin, roundcube, amavisd, clamAV, ...
:Virtualization: KVM, LXC, Docker, VirtualBox
:Other: Gitlab, Github, Redmine, OpenERP, ...
